/*
 * A test accessor producing generated content.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>
#include <string.h>

#include "test_file_accessor.h"

TestFileAccessor::TestFileAccessor(fileid_t fileid, offset_t size)
: Accessor(fileid, size)
{
}

/* Data transfer helper methods. */

void TestFileAccessor::fill_populated(Flexpage *flexpage)
{
    Region *region = flexpage->region;
    offset_t filepos = flexpage->base_offset;

    /* Tag the region with file state. */

    region->fill(fileid, filepos);

    /* Write some data to each page of the flexpage in each region. This
       allows each page to be tested regardless of how large each flexpage
       or region is. */

    offset_t addr = flexpage->base_addr;
    offset_t limit = addr + flexpage->size;

    while (addr < limit)
    {
        /* Overwrite enough of any previous data to make the new data
           readable. */

        char tag[32];

        sprintf(tag, "%ld:%ld", fileid, filepos);

        memset((void *) addr, 0, strlen(tag) + 1);
        strcpy((char *) addr, tag);

        filepos += PAGE_SIZE;
        addr += PAGE_SIZE;
    }
}

void TestFileAccessor::flush_populated(Flexpage *flexpage)
{
    flexpage->region->flush();
}

// vim: tabstop=4 expandtab shiftwidth=4
